==> clean_android_design-0.2.8.tar.gz: lib/src/utils/shimmer/shimmer.dart <==
import 'dart:math';

import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class Shimmer extends StatefulWidget {
  static ShimmerState? of(BuildContext context) {
    return context.findAncestorStateOfType<ShimmerState>();
  }

  const Shimmer({
    this.linearGradient,
    this.child,
  });

  final LinearGradient? linearGradient;
  final Widget? child;

  @override
  ShimmerState createState() => ShimmerState();
}

class ShimmerState extends State<Shimmer> with SingleTickerProviderStateMixin {
  late AnimationController _shimmerController;

  @override
  void initState() {
    super.initState();

    _shimmerController = AnimationController.unbounded(vsync: this)
      ..repeat(min: -0.5, max: 1.5, period: const Duration(milliseconds: 1000));

    randomKey = SplitRouterDelegate.instance.routePath
        .toString()
        .codeUnits
        .reduce((value, element) => value + element);
  }

  @override
  void dispose() {
    _shimmerController.dispose();
    super.dispose();
  }

  LinearGradient get defaultGradient => LinearGradient(
        colors: [
          DefaultColors.shimmerBackground,
          DefaultColors.shimmerForeground,
          DefaultColors.shimmerBackground,
        ],
        stops: [
          0.26,
          0.3,
          0.32,
        ],
        begin: Alignment(-1.0, -0.3),
        end: Alignment(1.0, 0.3),
        tileMode: TileMode.clamp,
      );

  LinearGradient get gradient => LinearGradient(
        colors: (widget.linearGradient ?? defaultGradient).colors,
        stops: (widget.linearGradient ?? defaultGradient).stops,
        begin: (widget.linearGradient ?? defaultGradient).begin,
        end: (widget.linearGradient ?? defaultGradient).end,
        transform:
            _SlidingGradientTransform(slidePercent: _shimmerController.value),
      );

  bool get isSized => (context.findRenderObject() as RenderBox).hasSize;

  Size get size => (context.findRenderObject() as RenderBox).size;

  Offset getDescendantOffset({
    required RenderBox descendant,
    Offset offset = Offset.zero,
  }) {
    final shimmerBox = context.findRenderObject() as RenderBox;
    return descendant.localToGlobal(offset, ancestor: shimmerBox);
  }

  Listenable get shimmerChanges => _shimmerController;

  @override
  Widget build(BuildContext context) {
    return widget.child ?? const SizedBox();
  }

  late int randomKey;
  int uses = 0;

  double get getRandomShort => random.nextDouble() * 100 + 50;
  double get getRandomLong => random.nextDouble() * 200 + 100;
  Random get random => Random(randomKey + uses++);
}

class _SlidingGradientTransform extends GradientTransform {
  const _SlidingGradientTransform({
    required this.slidePercent,
  });

  final double slidePercent;

  @override
  Matrix4? transform(Rect bounds, {TextDirection? textDirection}) {
    return Matrix4.translationValues(bounds.width * slidePercent, 0.0, 0.0);
  }
}

==> clean_android_design-0.2.19.tar.gz: lib/src/utils/shimmer/shimmer.dart <==
import 'dart:math';

import 'package:clean_android_design/clean_android_design.dart';
import 'package:flutter/material.dart';

class Shimmer extends StatefulWidget {
  static ShimmerState? of(BuildContext context) {
    return context.findAncestorStateOfType<ShimmerState>();
  }

  const Shimmer({
    this.linearGradient,
    this.child,
  });

  final LinearGradient? linearGradient;
  final Widget? child;

  @override
  ShimmerState createState() => ShimmerState();
}

class ShimmerState extends State<Shimmer> with SingleTickerProviderStateMixin {
  late AnimationController _shimmerController;

  @override
  void initState() {
    super.initState();

    _shimmerController = AnimationController.unbounded(vsync: this)
      ..repeat(min: -0.5, max: 1.5, period: const Duration(milliseconds: 1000));

    randomKey = SplitRouterDelegate.hasInstance
        ? SplitRouterDelegate.instance.routePath
            .toString()
            .codeUnits
            .reduce((value, element) => value + element)
        : Random().nextInt(100000);
  }

  @override
  void dispose() {
    _shimmerController.dispose();
    super.dispose();
  }

  LinearGradient get defaultGradient => LinearGradient(
        colors: [
          DefaultColors.shimmerBackground,
          DefaultColors.shimmerForeground,
          DefaultColors.shimmerBackground,
        ],
        stops: [
          0.26,
          0.3,
          0.32,
        ],
        begin: Alignment(-1.0, -0.3),
        end: Alignment(1.0, 0.3),
        tileMode: TileMode.clamp,
      );

  LinearGradient get gradient => LinearGradient(
        colors: (widget.linearGradient ?? defaultGradient).colors,
        stops: (widget.linearGradient ?? defaultGradient).stops,
        begin: (widget.linearGradient ?? defaultGradient).begin,
        end: (widget.linearGradient ?? defaultGradient).end,
        transform:
            _SlidingGradientTransform(slidePercent: _shimmerController.value),
      );

  bool get isSized => (context.findRenderObject() as RenderBox).hasSize;

  Size get size => (context.findRenderObject() as RenderBox).size;

  Offset getDescendantOffset({
    required RenderBox descendant,
    Offset offset = Offset.zero,
  }) {
    final shimmerBox = context.findRenderObject() as RenderBox;
    return descendant.localToGlobal(offset, ancestor: shimmerBox);
  }

  Listenable get shimmerChanges => _shimmerController;

  @override
  Widget build(BuildContext context) {
    return widget.child ?? const SizedBox();
  }

  late int randomKey;
  int uses = 0;

  double get getRandomShort => random.nextDouble() * 100 + 50;
  double get getRandomLong => random.nextDouble() * 200 + 100;
  Random get random => Random(randomKey + uses++);
}

class _SlidingGradientTransform extends GradientTransform {
  const _SlidingGradientTransform({
    required this.slidePercent,
  });

  final double slidePercent;

  @override
  Matrix4? transform(Rect bounds, {TextDirection? textDirection}) {
    return Matrix4.translationValues(bounds.width * slidePercent, 0.0, 0.0);
  }
}
